@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::VERSION = '1.100980';
+}
 # ABSTRACT: Support for hierarchical exception classes
 use Carp;
 use Data::UUID;
@@ -90,7 +92,7 @@ Error::Hierarchy - Support for hierarchical exception classes
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 SYNOPSIS
 
@@ -234,11 +236,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
