@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy::Base;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::Base::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for hierarchical exception classes
 use parent qw(
   Error
@@ -41,7 +43,7 @@ Error::Hierarchy::Base - Base class for hierarchical exception classes
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 DESCRIPTION
 
@@ -60,6 +62,18 @@ component is initialized by calling the method of the same name with the given
 value. If called with a single hash reference, it is dereferenced and its
 key/value pairs are set as described before.
 
+Creates and returns a new object. The constructor will accept as arguments a
+list of pairs, from component name to initial value. For each pair, the named
+component is initialized by calling the method of the same name with the given
+value. If called with a single hash reference, it is dereferenced and its
+key/value pairs are set as described before.
+
+Examples:
+
+  my $obj = Error::Hierarchy::Base->new;
+
+  my $obj = Error::Hierarchy::Base->new(%args);
+
 =head2 stringify
 
 This class overloads C<""> to call this method. It defines how an exception
@@ -93,11 +107,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
