@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy::Container;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::Container::VERSION = '1.100980';
+}
 # ABSTRACT: Container for hierarchical exceptions
 use Data::Miscellany 'set_push';
 
@@ -43,7 +45,7 @@ Error::Hierarchy::Container - Container for hierarchical exceptions
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 SYNOPSIS
 
@@ -95,11 +97,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
