@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy::Internal;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::Internal::VERSION = '1.100980';
+}
 # ABSTRACT: Base class for internal exceptions
 
 use parent 'Error::Hierarchy';
@@ -29,7 +31,7 @@ Error::Hierarchy::Internal - Base class for internal exceptions
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 DESCRIPTION
 
@@ -78,11 +80,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
