@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy::Internal::Class;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::Internal::Class::VERSION = '1.100980';
+}
 # ABSTRACT: When you got an object of a wrong class
 use parent 'Error::Hierarchy::Internal';
 __PACKAGE__->mk_accessors(qw(class_expected class_got));
@@ -21,7 +23,7 @@ Error::Hierarchy::Internal::Class - When you got an object of a wrong class
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 SYNOPSIS
 
@@ -71,11 +73,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
