@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy::Internal::DBI::STH;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::Internal::DBI::STH::VERSION = '1.100980';
+}
 # ABSTRACT: DBI statement-related exception
 use Error::Hierarchy::Util 'load_class';
 use parent 'Error::Hierarchy::Internal::DBI::H';
@@ -83,7 +85,7 @@ Error::Hierarchy::Internal::DBI::STH - DBI statement-related exception
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 DESCRIPTION
 
@@ -156,11 +158,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
