@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy::Internal::NoHashRef;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::Internal::NoHashRef::VERSION = '1.100980';
+}
 # ABSTRACT: When you expected a hash reference
 use parent 'Error::Hierarchy::Internal::CustomMessage';
 1;
@@ -18,7 +20,7 @@ Error::Hierarchy::Internal::NoHashRef - When you expected a hash reference
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 DESCRIPTION
 
@@ -50,11 +52,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
