@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Error::Hierarchy::Mixin;
-our $VERSION = '1.100850';
+BEGIN {
+  $Error::Hierarchy::Mixin::VERSION = '1.100980';
+}
 # ABSTRACT: Provides often-used exception-related methods
 use Error;    # to get $Error::Depth
 
@@ -65,7 +67,7 @@ Error::Hierarchy::Mixin - Provides often-used exception-related methods
 
 =head1 VERSION
 
-version 1.100850
+version 1.100980
 
 =head1 SYNOPSIS
 
@@ -115,11 +117,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Error-Hierarchy/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
